@@ -53,13 +53,15 @@ class Lidar():
         
     def region(self):
         self.output_slider_variable = widgets.Text()
-        stream = pkg_resources.resource_stream(__name__, 'data/filename.txt')
+#         stream = pkg_resources.resource_stream(__name__, 'data/filename.txt')
+        my_resources = importlib_resources.files("agri-tech")
+        data = (my_resources / "data" / "filename.txt").read_bytes()
        
         # Define function to bind value of the input to the output variable 
         def f(x):
             self.output_slider_variable.value = str(x)
 
-        dropdown = interact(f, x=read_text(stream))
+        dropdown = interact(f, x=read_text(data))
         return self.output_slider_variable
 
     def ept_json(self):
